@@ -1,11 +1,10 @@
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 from rest_framework.serializers import SerializerMethodField
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.wechat.models import WeChatUser
 from bluedot_rest_framework.wechat.serializers import WeChatUserSerializer
 
-User = import_string(api_settings.USER['models'])
+User = import_string('USER.models')
 
 
 class UserSerializer(CustomSerializer):
